import { OnDestroy, OnInit, TemplateRef, ViewContainerRef } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { ReplaySubject } from 'rxjs/internal/ReplaySubject';
import { NrfFormDirective } from '../form/form.directive';
import { NrfFormService } from '../form/form.service';
import { NrfControlOptions } from './control-options.component';
import { NrfModelSetterService } from './model-setter.service';
/**
 * This directive control nested inputs and sets values on the Original Model set at {@link NrfFormDirective#nrfEntity}
 *
 * #### Given an nrfEntity on the controller:
 * ```typescript
 * this.userModel = {
 *    firstName: 'John',
 *    address: {
 *        street: 'Carnaby Street'
 *    }
 * };
 * ```
 *
 * #### Use it on the form
 * ```html
 * <form [nrfEntity]="userModel">
 *   <div class="form-group">
 *      <label for="name">Name:</label>
 *
 *      <div *nrfNestedControl="'userModel.firstName'; let control=formControl">
 *        <input [formControl]="control" />
 *      </div>
 *   </div>
 * </form>
 * ```
 */
export declare class NrfNestedControlDirective implements OnInit, OnDestroy {
    private readonly modelSetter;
    private readonly templateRef;
    private readonly viewContainerRef;
    isDestroyed: boolean;
    parentFormGroup: FormGroup;
    formControl: FormControl;
    /**
     * Used to set and get value on the entity model
     */
    modelPath: string;
    /**
     * Holds an instance of a NrfForm or a NrfService.
     * If the form is wrapped inside a directive with ng-content, the NrfFormService MUST be provided.
     * Otherwise the nrfForm will be used.
     */
    private formOrService;
    constructor(modelSetter: NrfModelSetterService, templateRef: TemplateRef<any>, viewContainerRef: ViewContainerRef, nrfForm: NrfFormDirective, nrfFormService: NrfFormService);
    /**
     * The dot notation full name of the nrfEntity
     */
    nrfModelName: string;
    /**
     * [AbstractControlOptions]{@link https://angular.io/api/forms/AbstractControlOptions}
     * containing the validators list and the update-on strategy
     *
     * It will be set on the formControl while initiating a new one.
     */
    controlOptions: NrfControlOptions;
    /**
     * Emit right after the view were rendered and the component and its variables ara available.
     */
    readonly ready$: ReplaySubject<{}>;
    /**
     * Register this input component to its parent form [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     *
     * And starts to emit the input's value when it changes.
     */
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
    * Return the dot notation path of the Entity, without the first part,
    * because it is the Entity itself.
    */
    private getModelPathWithoutFirstPart();
    /**
     * Instantiate a new [FormControl]{@link https://angular.io/api/forms/FormControl} and return it
     */
    protected getNewFormControl(): FormControl;
    /**
     * Get the value from the [nrfEntity]{@link NrfFormDirective#nrfEntity}
     */
    protected getInitialValue(): any | null;
    private showViewContent();
    /**
     * Register this input to its parent [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     * to enable validations and data manipulation
     */
    private registerToFormGroup();
    /**
     * Verify if this input is inside a [NrfFormDirective]{@link NrfFormDirective}
     * and return its [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     *
     * Otherwise a new empty [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     */
    private getParentFormGroup();
    /**
     * Verify if the [FormGroup]{@link https://angular.io/api/forms/FormGroup} has an control with the current name and return it.
     * Otherwise return a new [FormControl]{@link https://angular.io/api/forms/FormControl}
     */
    protected getFormControl(): FormControl;
    /**
     * Subscribe to [valueChanges]{@link https://angular.io/api/forms/AbstractControl#valueChanges} and update the Entity value
     */
    private subscribeToUpdateEntityValue();
    /**
     * Set the value to the [formData]{@link NrfFormDirective#formData}
     */
    setModelValue(newValue: any): void;
    emitReadyState(): void;
}
